@@ -24,17 +24,14 @@ import gio
 import glib
 import logging
 import pango
-from gnome import help_display_uri
 
 from usbcreator.frontends.base import Frontend
 from usbcreator.misc import *
 
 if 'USBCREATOR_LOCAL' in os.environ:
     ui_path = os.path.join(os.getcwd(), 'gui/usbcreator-gtk.ui')
-    icon_path = os.path.join(os.getcwd(), 'desktop/usb-creator-gtk.png')
 else:
     ui_path = '/usr/share/usb-creator/usbcreator-gtk.ui'
-    icon_path = '/usr/share/pixmaps/usb-creator-gtk.png'
 
 gtk.gdk.threads_init()
 
@@ -82,7 +79,10 @@ class GtkFrontend(Frontend):
         from dbus.mainloop.glib import DBusGMainLoop
         DBusGMainLoop(set_as_default=True)
 
-    def __init__(self, backend, img=None, persistent=True):
+    def __init__(self, backend, img=None, persistent=True,
+                 allow_system_internal=False):
+
+        self.allow_system_internal = allow_system_internal
 
         self.all_widgets = set()
 
@@ -109,7 +109,7 @@ class GtkFrontend(Frontend):
                 widget.set_name(gtk.Buildable.get_name(widget))
                 setattr(self, gtk.Widget.get_name(widget), widget)
 
-        gtk.window_set_default_icon_from_file(icon_path)
+        gtk.window_set_default_icon_name('usb-creator-gtk')
         for w in self.all_widgets:
             process_labels(w)
 
@@ -119,7 +119,9 @@ class GtkFrontend(Frontend):
         self.finished_exit.connect('clicked', lambda x: self.finished_dialog.hide())
         self.failed_exit.connect('clicked', lambda x: self.failed_exit.hide())
         self.progress_cancel_button.connect('clicked', lambda x: self.warning_dialog.show())
-        self.button_help.connect('clicked', lambda x: help_display_uri('ghelp:usb-creator'))
+        self.button_help.connect('clicked', lambda x: gtk.show_uri(self.button_help.get_screen(),
+                                                                   'ghelp:usb-creator',
+                                                                   gtk.get_current_event_time()))
 
         def format_value(scale, value):
             return format_mb_size(value)
@@ -163,6 +165,9 @@ class GtkFrontend(Frontend):
                 if fname.endswith('.iso') or fname.endswith('.img'):
                     self.backend.add_image(os.path.join(download_dir, fname))
 
+        # Sets first pre-populated image as current in the backend
+        self.selection_changed_source(self.source_treeview.get_selection())
+
         if not persistent:
             self.persist_disabled.set_active(True)
             self.persist_vbox.hide()
@@ -444,9 +449,10 @@ class GtkFrontend(Frontend):
         status = target['status']
         source = self.backend.get_current_source()
         if not source:
+            self.button_install.set_sensitive(False)
             return
         stype = self.backend.sources[source]['type']
-        if status == CAN_USE or stype == SOURCE_IMG:
+        if status == CAN_USE:
             self.button_install.set_sensitive(True)
         else:
             self.button_install.set_sensitive(False)
@@ -604,7 +610,8 @@ class GtkFrontend(Frontend):
             self.window.hide()
             self.delete_timeout(self.update_loop)
             try:
-                self.backend.install(source, target, persist)
+                self.backend.install(source, target, persist,
+                                     allow_system_internal=self.allow_system_internal)
             except:
                 self._fail()
 
