@@ -477,6 +477,8 @@ class install(Thread):
                 logging.debug('mkdir %s' % os.path.join(self.target, line[2]))
                 os.mkdir(os.path.join(self.target, line[2]))
 
+        self.install_efi()
+
         grub = os.path.join(self.target, 'boot', 'grub', 'i386-pc')
         if os.path.isdir(grub):
             self.install_bootloader(grub)
@@ -487,6 +489,29 @@ class install(Thread):
         self.create_persistence()
         self.sync()
 
+    def install_efi(self):
+        logging.debug('install_efi')
+        self.progress_pulse()
+        self.progress_message(_('Installing the EFI bootloader...'))
+        message = _('Failed to install the EFI bootloader.')
+        efi_file = os.path.join(self.target, 'efi', 'boot', 'bootx64.efi')
+        efi_image = os.path.join(self.target, 'boot', 'grub', 'efi.img')
+        if os.path.exists(efi_file):
+            return
+        if not os.path.exists(efi_image):
+            return
+        import dbus
+        try:
+            bus = dbus.SystemBus()
+            obj = bus.get_object('com.ubuntu.USBCreator',
+                                 '/com/ubuntu/USBCreator')
+            obj.InstallEFI(self.target, efi_image,
+                                  dbus_interface='com.ubuntu.USBCreator',
+                                  timeout=MAX_DBUS_TIMEOUT)
+        except dbus.DBusException:
+            self._failure(message)
+
+
     def install(self):
         # Some of the code in this function was copied from Ubiquity's
         # scripts/install.py
@@ -548,6 +573,8 @@ class install(Thread):
                         os.unlink(targetpath)
                     self.copy_file(sourcepath, targetpath)
 
+        self.install_efi()
+
         grub = os.path.join(self.target, 'boot', 'grub', 'i386-pc')
         if os.path.isdir(grub):
             self.install_bootloader(grub)
